import { EventEmitter, AfterContentInit, OnDestroy, ViewContainerRef, NgZone, ComponentFactoryResolver, Renderer2, Injector } from '@angular/core';
import { XamFunnelChart } from './XamFunnelChart';
import { Visibility } from "igniteui-angular-core";
import { OuterLabelAlignment } from './OuterLabelAlignment';
import { FunnelSliceDisplay } from './FunnelSliceDisplay';
import { IgxFunnelSliceClickedEventArgs } from './igx-funnel-slice-clicked-event-args';
import { IgDataTemplate } from "igniteui-angular-core";
export declare const IgxFunnelChartComponent_PROVIDERS: any[];
/**
 * Represents a funnel chart.
*/
export declare class IgxFunnelChartComponent implements AfterContentInit, OnDestroy {
    private renderer;
    private _elRef;
    private ngZone;
    private injector;
    private componentFactoryResolver;
    container: Element;
    _dynamicContent: ViewContainerRef;
    private _height;
    private _width;
    height: string;
    width: string;
    private _root;
    constructor(renderer: Renderer2, _elRef: ViewContainerRef, ngZone: NgZone, injector: Injector, componentFactoryResolver: ComponentFactoryResolver);
    ngAfterContentInit(): void;
    ngOnDestroy(): void;
    private _wrapper;
    protected createImplementation(): XamFunnelChart;
    protected createSeriesComponent(type: string): any;
    private _chart;
    private _dataSource;
    dataSource: Array<any>;
    bindData(): void;
    /**
     * Gets or sets the legend used for the current chart.
    */
    legend: any;
    protected _implementation: any;
    /**
     * @hidden
     */
    readonly i: XamFunnelChart; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgxFunnelChartComponent;
    /**
 * Gets or sets the value member path for the funnel chart.
*/
    valueMemberPath: string;
    /**
     * Gets or sets the palette of brushes to use for coloring the slices.
    */
    brushes: string[];
    static ngAcceptInputType_brushes: string[] | string;
    /**
     * Gets or sets the palette of brushes to use for outlines on the slices.
    */
    outlines: string[];
    static ngAcceptInputType_outlines: string[] | string;
    /**
     * Gets or sets the percentage (from near 0 to 1) of space the bottom edge of the funnel should take.
    */
    bottomEdgeWidth: number;
    static ngAcceptInputType_bottomEdgeWidth: number | string;
    /**
     * Gets or sets the InnerLabel mapping property for the current series object.
    */
    innerLabelMemberPath: string;
    /**
     * Gets or sets the OuterLabel mapping property for the current series object.
    */
    outerLabelMemberPath: string;
    /**
     * Gets or sets whether the inner labels are visible.
    */
    innerLabelVisibility: Visibility;
    static ngAcceptInputType_innerLabelVisibility: Visibility | string;
    /**
     * Gets or sets whether the outer labels are visible.
    */
    outerLabelVisibility: Visibility;
    static ngAcceptInputType_outerLabelVisibility: Visibility | string;
    /**
     * Gets or sets which side of the chart the outer labels should appear.
    */
    outerLabelAlignment: OuterLabelAlignment;
    static ngAcceptInputType_outerLabelAlignment: OuterLabelAlignment | string;
    /**
     * Gets or sets how the heights of the funnel slices should be configured.
    */
    funnelSliceDisplay: FunnelSliceDisplay;
    static ngAcceptInputType_funnelSliceDisplay: FunnelSliceDisplay | string;
    /**
     * Gets or sets the formatter function for inner labels. Function should return string and it takes 3 parameters: 1st-value of item to format, 2nd-index of item within data, 3rd-reference to the funnel chart.
    */
    formatInnerLabel: (arg1: any, arg2: number, arg3: any) => string;
    /**
     * Gets or sets the formatter function for outer labels. Function should return string and it takes 3 parameters: 1st-value of item to format, 2nd-index of item within data, 3rd-reference to the funnel chart.
    */
    formatOuterLabel: (arg1: any, arg2: number, arg3: any) => string;
    /**
     * Gets or sets how long the animations should take to run.
    */
    transitionDuration: number;
    static ngAcceptInputType_transitionDuration: number | string;
    /**
     * Gets or sets if the funnel should be rendered inverted.
    */
    isInverted: boolean;
    static ngAcceptInputType_isInverted: boolean | string;
    /**
     * Gets or sets whether to use a Bezier curve to define the funnel.
    */
    useBezierCurve: boolean;
    static ngAcceptInputType_useBezierCurve: boolean | string;
    /**
     * Gets or sets whether to allow slices to be selected.
    */
    allowSliceSelection: boolean;
    static ngAcceptInputType_allowSliceSelection: boolean | string;
    /**
     * Gets or sets whether to use the unselected style on unselected slices.
    */
    useUnselectedStyle: boolean;
    static ngAcceptInputType_useUnselectedStyle: boolean | string;
    /**
     * Gets or sets the fill brush.
    */
    selectedSliceFill: string;
    /**
     * Gets or sets the stroke brush.
    */
    selectedSliceStroke: string;
    /**
     * Gets or sets the stroke thickness.
    */
    selectedSliceStrokeThickness: number;
    static ngAcceptInputType_selectedSliceStrokeThickness: number | string;
    /**
     * Gets or sets the opacity.
    */
    selectedSliceOpacity: number;
    static ngAcceptInputType_selectedSliceOpacity: number | string;
    ensureSelectedSliceStyle(): void;
    /**
     * Gets or sets the fill brush.
    */
    unselectedSliceFill: string;
    /**
     * Gets or sets the stroke brush.
    */
    unselectedSliceStroke: string;
    /**
     * Gets or sets the stroke thickness.
    */
    unselectedSliceStrokeThickness: number;
    static ngAcceptInputType_unselectedSliceStrokeThickness: number | string;
    /**
     * Gets or sets the opacity.
    */
    unselectedSliceOpacity: number;
    static ngAcceptInputType_unselectedSliceOpacity: number | string;
    ensureUnselectedSliceStyle(): void;
    /**
     * Gets or sets the LegendItemBadgeTemplate to use for the legend items.
    */
    legendItemBadgeTemplate: IgDataTemplate;
    /**
     * Gets or sets whether to use the outer labels to identify the legend items.
    */
    useOuterLabelsForLegend: boolean;
    static ngAcceptInputType_useOuterLabelsForLegend: boolean | string;
    /**
     * Gets or sets the text style for inner labels
    */
    textStyle: string;
    /**
     * Gets or sets the text style for outer labels
    */
    outerLabelTextStyle: string;
    /**
     * Gets or sets the thickness of outline around slices.
    */
    outlineThickness: number;
    static ngAcceptInputType_outlineThickness: number | string;
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    pixelScalingRatio: number;
    static ngAcceptInputType_pixelScalingRatio: number | string;
    /**
     * Gets or sets the brush used for the outer labels.
    */
    outerLabelTextColor: string;
    /**
     * Gets or sets the brush used for the inner labels.
    */
    textColor: string;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected readonly hasUserValues: Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Provides container for funnel chart

*/
    provideContainer(container: any): void;
    /**
     * Notifies the controller and view about a size change.
    
    */
    notifyResized(): void;
    notifySetItem(source_: any, index: number, oldItem: any, newItem: any): void;
    /**
     * Manually notifies the chart's data source that the data it has bound to has been cleared and needs to be re-examined.
     * This should not be called if the data that the chart is bound to is already observable.
    
    */
    notifyClearItems(source_: any): void;
    notifyInsertItem(source_: any, index: number, newItem: any): void;
    notifyRemoveItem(source_: any, index: number, oldItem: any): void;
    /**
     * Toggle selection of item at index.
    
    */
    toggleSelection(index: number): void;
    /**
     * Exports and serializes the chart visuals.
    
    */
    exportSerializedVisualData(): string;
    private _sliceClicked;
    /**
     * Event which is raised when a slice is clicked.
     * Function takes first argument null and second argument ui.
     * Use ui.owner to obtain reference to igFunnelChart.
     * Use ui.index to obtain index of clicked slice.
     * Use ui.item to obtain reference to clicked slice item.
     * Use ui.selected to check if slice became selected.
    */
    readonly sliceClicked: EventEmitter<{
        sender: any;
        args: IgxFunnelSliceClickedEventArgs;
    }>;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
}
