import { OnDestroy, TemplateRef, Injector, ComponentFactoryResolver, AfterContentInit, Renderer2, NgZone, ViewContainerRef } from '@angular/core';
import { Visibility } from "igniteui-angular-core";
import { XamSparkline } from './XamSparkline';
import { SparklineVisualData } from './SparklineVisualData';
import { TrendLineType } from "igniteui-angular-core";
import { SparklineDisplayType } from './SparklineDisplayType';
import { UnknownValuePlotting } from "igniteui-angular-core";
export declare const IgxSparklineComponent_PROVIDERS: any[];
/**
 * Represents a sparkline chart.
*/
export declare class IgxSparklineComponent implements AfterContentInit, OnDestroy {
    private _renderer;
    private _elRef;
    private _ngZone;
    private _componentFactoryResolver;
    private _injector;
    _dynamicContent: ViewContainerRef;
    private _height;
    private _width;
    height: string;
    width: string;
    private _container;
    private _dataSource;
    dataSource: any;
    private _root;
    constructor(_renderer: Renderer2, _elRef: ViewContainerRef, _ngZone: NgZone, _componentFactoryResolver: ComponentFactoryResolver, _injector: Injector);
    ngOnDestroy(): void;
    private _wrapper;
    protected createImplementation(): XamSparkline;
    private _sparkline;
    ngAfterContentInit(): void;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
    private _tooltipTemplate;
    private _tooltipContent;
    tooltipTemplate: TemplateRef<any>;
    private _ensureTooltipCreated;
    private createWrapper;
    private _defaultTooltips;
    private _ensureDefaultTooltip;
    private _onDefaultTooltipsReady;
    private createTooltip;
    protected _implementation: any;
    /**
     * @hidden
     */
    readonly i: XamSparkline; /**
                                 * @hidden
                                 */
    static _createFromInternal(internal: any): IgxSparklineComponent;
    /**
 * Gets or sets the sparkline brush.
*/
    brush: string;
    /**
     * Gets or sets the negative brush of the sparkline.
    */
    negativeBrush: string;
    /**
     * Gets or sets the marker brush of the sparkline.
    */
    markerBrush: string;
    /**
     * Gets or sets the negative marker brush of the sparkline.
    */
    negativeMarkerBrush: string;
    /**
     * Gets or sets the first marker brush of the sparkline.
    */
    firstMarkerBrush: string;
    /**
     * Gets or sets the last marker brush of the sparkline.
    */
    lastMarkerBrush: string;
    /**
     * Gets or sets the high marker brush of the sparkline.
    */
    highMarkerBrush: string;
    /**
     * Gets or sets the low marker brush of the sparkline.
    */
    lowMarkerBrush: string;
    /**
     * Gets or sets the trendline brush of the sparkline.
    */
    trendLineBrush: string;
    /**
     * Gets or sets the horizontal axis line brush of the sparkline.
    */
    horizontalAxisBrush: string;
    /**
     * Gets or sets the vertical axis line brush of the sparkline.
    */
    verticalAxisBrush: string;
    /**
     * Gets or sets the normal range brush of the sparkline.
    */
    normalRangeFill: string;
    /**
     * Gets or sets the display state of the horizontal axis.
    */
    horizontalAxisVisibility: Visibility;
    static ngAcceptInputType_horizontalAxisVisibility: Visibility | string;
    /**
     * Gets or sets the display state of the vertical axis.
    */
    verticalAxisVisibility: Visibility;
    static ngAcceptInputType_verticalAxisVisibility: Visibility | string;
    /**
     * Gets or sets the marker visibility of the sparkline.
    */
    markerVisibility: Visibility;
    static ngAcceptInputType_markerVisibility: Visibility | string;
    /**
     * Gets or sets the negative marker visibility of the sparkline.
    */
    negativeMarkerVisibility: Visibility;
    static ngAcceptInputType_negativeMarkerVisibility: Visibility | string;
    /**
     * Gets or sets the first marker visibility of the sparkline.
    */
    firstMarkerVisibility: Visibility;
    static ngAcceptInputType_firstMarkerVisibility: Visibility | string;
    /**
     * Gets or sets the last marker visibility of the sparkline.
    */
    lastMarkerVisibility: Visibility;
    static ngAcceptInputType_lastMarkerVisibility: Visibility | string;
    /**
     * Gets or sets the low marker visibility of the sparkline.
    */
    lowMarkerVisibility: Visibility;
    static ngAcceptInputType_lowMarkerVisibility: Visibility | string;
    /**
     * Gets or sets the high marker visibility of the sparkline.
    */
    highMarkerVisibility: Visibility;
    static ngAcceptInputType_highMarkerVisibility: Visibility | string;
    /**
     * Gets or sets the normal range visibility of the sparkline.
    */
    normalRangeVisibility: Visibility;
    static ngAcceptInputType_normalRangeVisibility: Visibility | string;
    /**
     * Gets or sets the position of the normal range on the sparkline.
    */
    displayNormalRangeInFront: boolean;
    static ngAcceptInputType_displayNormalRangeInFront: boolean | string;
    /**
     * Gets or sets the marker size of the sparkline.
    */
    markerSize: number;
    static ngAcceptInputType_markerSize: number | string;
    /**
     * Gets or sets the first marker size of the sparkline.
    */
    firstMarkerSize: number;
    static ngAcceptInputType_firstMarkerSize: number | string;
    /**
     * Gets or sets the last marker size of the sparkline.
    */
    lastMarkerSize: number;
    static ngAcceptInputType_lastMarkerSize: number | string;
    /**
     * Gets or sets the high marker size of the sparkline.
    */
    highMarkerSize: number;
    static ngAcceptInputType_highMarkerSize: number | string;
    /**
     * Gets or sets the low marker size of the sparkline.
    */
    lowMarkerSize: number;
    static ngAcceptInputType_lowMarkerSize: number | string;
    /**
     * Gets or sets the negative marker size of the sparkline.
    */
    negativeMarkerSize: number;
    static ngAcceptInputType_negativeMarkerSize: number | string;
    /**
     * Gets or sets the line thickness of the sparkline.
    */
    lineThickness: number;
    static ngAcceptInputType_lineThickness: number | string;
    /**
     * Gets or sets the minimum value of the y axis.
    */
    minimum: number;
    static ngAcceptInputType_minimum: number | string;
    /**
     * Gets or sets the maximum value of the y axis.
    */
    maximum: number;
    static ngAcceptInputType_maximum: number | string;
    /**
     * Gets or sets the string path to the value column.
    */
    valueMemberPath: string;
    /**
     * String identifier of a column or property name to get labels from on each item in the data source.  These labels will be retrieved from the first and last item, and displayed by the horizontal axis.
    */
    labelMemberPath: string;
    /**
     * Gets or sets the type of trendline used by the sparkline.
    */
    trendLineType: TrendLineType;
    static ngAcceptInputType_trendLineType: TrendLineType | string;
    /**
     * Gets or sets the trendline period used by the sparkline.
    */
    trendLinePeriod: number;
    static ngAcceptInputType_trendLinePeriod: number | string;
    /**
     * Gets or sets the thickness of the sparkline's trendline.
    */
    trendLineThickness: number;
    static ngAcceptInputType_trendLineThickness: number | string;
    /**
     * Gets or sets the minimum value of the normal range.
    */
    normalRangeMinimum: number;
    static ngAcceptInputType_normalRangeMinimum: number | string;
    /**
     * Gets or sets the maximum value of the normal range.
    */
    normalRangeMaximum: number;
    static ngAcceptInputType_normalRangeMaximum: number | string;
    /**
     * Gets or sets the display type of the sparkline.
    */
    displayType: SparklineDisplayType;
    static ngAcceptInputType_displayType: SparklineDisplayType | string;
    /**
     * Gets or sets the way null values are interpreted.
    */
    unknownValuePlotting: UnknownValuePlotting;
    static ngAcceptInputType_unknownValuePlotting: UnknownValuePlotting | string;
    /**
     * The value or content to display on the vertical axis.
     * This can be set to a formatted string, such as "{0:n}", or it can be set to a DataTemplate.
    */
    verticalAxisLabel: any;
    /**
     * The value or content to display on the horizontal axis.
     * This can be set to a formatted string, such as "{0}", or it can be set to a DataTemplate.
    */
    horizontalAxisLabel: any;
    /**
     * Sets or gets a function which takes an object that produces a formatted label for displaying in the chart.
    */
    formatLabel: (arg1: any) => string;
    /**
     * Gets or sets the label composite format used when creating label values.
    */
    horizontalLabelFormat: string;
    /**
     * Gets or sets the format specifiers to use with the HorizontalLabelFormat string.
    */
    horizontalLabelFormatSpecifiers: any[];
    static ngAcceptInputType_horizontalLabelFormatSpecifiers: any[] | string;
    /**
     * Gets or sets the label composite format used when creating label values.
    */
    verticalLabelFormat: string;
    /**
     * Gets or sets the format specifiers to use with the VerticalLabelFormat string.
    */
    verticalLabelFormatSpecifiers: any[];
    static ngAcceptInputType_verticalLabelFormatSpecifiers: any[] | string;
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    pixelScalingRatio: number;
    static ngAcceptInputType_pixelScalingRatio: number | string;
    /**
     * Gets the actual scaling value used by the component to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    actualPixelScalingRatio: number;
    static ngAcceptInputType_actualPixelScalingRatio: number | string;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected readonly hasUserValues: Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Provides a container to the sparkline control.

* @param container  * The container.
*/
    provideContainer(container: any): void;
    /**
     * Notify that the control has resized.
    
    */
    notifyResized(): void;
    notifySetItem(source_: any, index: number, oldItem: any, newItem: any): void;
    /**
     * Used to manually notify the IgxSparklineComponent that the data source has reset or cleared its items.  Invoking this method is only necessary if that datasource is not observable.
    
    * @param source_  * The data source which was cleared or reset.
    */
    notifyClearItems(source_: any): void;
    notifyInsertItem(source_: any, index: number, newItem: any): void;
    notifyRemoveItem(source_: any, index: number, oldItem: any): void;
    /**
     * Returns the sparkline visuals expressed as a SparklineVisualData object.
    
    */
    exportVisualData(): SparklineVisualData;
    /**
     * Returns visuals as a serialized string.
    
    */
    exportSerializedVisualData(): string;
}
