import { EventEmitter, ViewContainerRef, Injector, ComponentFactoryResolver, AfterContentInit, Renderer2, QueryList, NgZone } from '@angular/core';
import { IgPoint } from "igniteui-angular-core";
import { Treemap } from "./Treemap";
import { IgxTreemapNodeStyleMappingComponent } from './igx-treemap-node-style-mapping-component';
import { IgxTreemapNodeStyleMappingCollection } from './igx-treemap-node-style-mapping-collection';
import { TreemapFillScaleMode } from "./TreemapFillScaleMode";
import { IgxTreemapNodeStylingEventArgs } from "./igx-treemap-node-styling-event-args";
import { TreemapOrientation } from './TreemapOrientation';
import { TreemapLayoutType } from './TreemapLayoutType';
import { IgxTreemapNodePointerEventArgs } from './igx-treemap-node-pointer-event-args';
import { TreemapHeaderDisplayMode } from './TreemapHeaderDisplayMode';
import { HorizontalAlignment } from "igniteui-angular-core";
import { VerticalAlignment } from "igniteui-angular-core";
import { TreemapLabelHorizontalFitMode } from './TreemapLabelHorizontalFitMode';
import { TreemapLabelVerticalFitMode } from './TreemapLabelVerticalFitMode';
export declare const IgxTreemapComponent_PROVIDERS: any[];
export declare class IgxTreemapComponent implements AfterContentInit {
    private renderer;
    private _elRef;
    private ngZone;
    private injector;
    private componentFactoryResolver;
    container: Element;
    private _height;
    private _width;
    height: string;
    width: string;
    _dynamicContent: ViewContainerRef;
    contentStyleMappings: QueryList<IgxTreemapNodeStyleMappingComponent>;
    /**
    * The style mappings actually present in the chart. Do not directly modify this array.
    * This array's contents can be modified by causing Angular to reproject the child content.
    * Or adding and removing stye mappings from the manual style mapping collection on the styleMappings property.
    */
    actualStyleMappings: IgxTreemapNodeStyleMappingComponent[];
    private _styleMappings;
    private _styleMappingsAdapter;
    /**
     * A collection or manually added axes for the chart.
    */
    readonly styleMappings: IgxTreemapNodeStyleMappingCollection;
    private _wrapper;
    private _root;
    constructor(renderer: Renderer2, _elRef: ViewContainerRef, ngZone: NgZone, injector: Injector, componentFactoryResolver: ComponentFactoryResolver);
    updateStyle(): void;
    ngOnDestroy(): void;
    private _implementation;
    ngAfterContentInit(): void;
    protected createImplementation(): Treemap;
    readonly i: Treemap;
    private _treeMap;
    /**
 * Gets or sets path to use to get the values from the items.
*/
    valueMemberPath: string;
    /**
     * Gets or sets the root title to use for breadcrumbs.
    */
    rootTitle: string;
    /**
     * Gets or sets the root title to use for breadcrumbs.
    */
    breadcrumbSequence: string;
    /**
     * Gets or sets the path to use to get the Parent of the items.
    */
    parentIdMemberPath: string;
    /**
     * Gets or sets the path to use to get the Label of the items.
    */
    labelMemberPath: string;
    /**
     * Gets or sets the path to use to get the custom value of the items.
    */
    customValueMemberPath: string;
    /**
     * Gets or sets the path to use to get the id of the items.
    */
    idMemberPath: string;
    /**
     * Gets or sets the (possibly hierarchical) data to assign to the TreeMap.
    */
    dataSource: any[];
    /**
     * Gets or sets brushes to use for the fill scale.
    */
    fillBrushes: string[];
    static ngAcceptInputType_fillBrushes: string[] | string;
    /**
     * Gets or sets mode to use for the fill scale.
    */
    fillScaleMode: TreemapFillScaleMode;
    static ngAcceptInputType_fillScaleMode: TreemapFillScaleMode | string;
    /**
     * Gets or sets whether the fill scale is logarithmic.
    */
    isFillScaleLogarithmic: boolean;
    static ngAcceptInputType_isFillScaleLogarithmic: boolean | string;
    /**
     * Gets or sets the logarithm base to use if the fill scale is logarithmic.
    */
    fillScaleLogarithmBase: number;
    static ngAcceptInputType_fillScaleLogarithmBase: number | string;
    /**
     * Gets or sets the minimum value to use for the fill scale.
    */
    fillScaleMinimumValue: number;
    static ngAcceptInputType_fillScaleMinimumValue: number | string;
    /**
     * Gets or sets the maximum value to use for the fill scale.
    */
    fillScaleMaximumValue: number;
    static ngAcceptInputType_fillScaleMaximumValue: number | string;
    /**
     * Gets or sets the vertical fit mode to use for the node labels.
    */
    labelVerticalFitMode: TreemapLabelVerticalFitMode;
    static ngAcceptInputType_labelVerticalFitMode: TreemapLabelVerticalFitMode | string;
    /**
     * Gets or sets the horizontal fit mode to use for the node labels.
    */
    labelHorizontalFitMode: TreemapLabelHorizontalFitMode;
    static ngAcceptInputType_labelHorizontalFitMode: TreemapLabelHorizontalFitMode | string;
    /**
     * Gets or sets the background to use for the overlay header when it is hovered.
    */
    overlayHeaderHoverBackground: string;
    /**
     * Gets or sets the background to use for the header when it is hovered.
    */
    headerHoverBackground: string;
    /**
     * Gets or sets the background to use for the header.
    */
    headerBackground: string;
    /**
     * Gets or sets the background to use for the overlay header.
    */
    overlayHeaderBackground: string;
    /**
     * Gets or sets the text color to use for the header.
    */
    headerTextColor: string;
    /**
     * Gets or sets the dark text color to use for the header.
    */
    headerDarkTextColor: string;
    /**
     * Gets or sets the text color to use for the nodes.
    */
    textColor: string;
    /**
     * Gets or sets the dark text color to use for the nodes.
    */
    darkTextColor: string;
    /**
     * Gets or sets the text color to use for the header.
    */
    headerHoverTextColor: string;
    /**
     * Gets or sets the dark text color to use for the header when hovered.
    */
    headerHoverDarkTextColor: string;
    /**
     * Gets or sets the font to use for content nodes
    */
    textStyle: string;
    /**
     * Gets or sets the font to use for header nodes
    */
    headerTextStyle: string;
    /**
     * Gets or sets the font to use for header nodes
    */
    headerDisplayMode: TreemapHeaderDisplayMode;
    static ngAcceptInputType_headerDisplayMode: TreemapHeaderDisplayMode | string;
    /**
     * Gets or sets the left margin to use for the header.
    */
    headerLabelLeftMargin: number;
    static ngAcceptInputType_headerLabelLeftMargin: number | string;
    /**
     * Gets or sets the top margin to use for the header.
    */
    headerLabelTopMargin: number;
    static ngAcceptInputType_headerLabelTopMargin: number | string;
    /**
     * Gets or sets the right margin to use for the header.
    */
    headerLabelRightMargin: number;
    static ngAcceptInputType_headerLabelRightMargin: number | string;
    /**
     * Gets or sets the bottom margin to use for the header.
    */
    headerLabelBottomMargin: number;
    static ngAcceptInputType_headerLabelBottomMargin: number | string;
    /**
     * Gets or sets the left margin to use for the overlay header.
    */
    overlayHeaderLabelLeftMargin: number;
    static ngAcceptInputType_overlayHeaderLabelLeftMargin: number | string;
    /**
     * Gets or sets the top margin to use for the overlay header.
    */
    overlayHeaderLabelTopMargin: number;
    static ngAcceptInputType_overlayHeaderLabelTopMargin: number | string;
    /**
     * Gets or sets the right margin to use for the overlay header.
    */
    overlayHeaderLabelRightMargin: number;
    static ngAcceptInputType_overlayHeaderLabelRightMargin: number | string;
    /**
     * Gets or sets the bottom margin to use for the overlay header.
    */
    overlayHeaderLabelBottomMargin: number;
    static ngAcceptInputType_overlayHeaderLabelBottomMargin: number | string;
    /**
     * Gets or sets the left margin to use for the labels.
    */
    labelLeftMargin: number;
    static ngAcceptInputType_labelLeftMargin: number | string;
    /**
     * Gets or sets the top margin to use for the labels.
    */
    labelTopMargin: number;
    static ngAcceptInputType_labelTopMargin: number | string;
    /**
     * Gets or sets the right margin to use for the labels.
    */
    labelRightMargin: number;
    static ngAcceptInputType_labelRightMargin: number | string;
    /**
     * Gets or sets the bottom margin to use for the labels.
    */
    labelBottomMargin: number;
    static ngAcceptInputType_labelBottomMargin: number | string;
    /**
     * Gets or sets the left margin to use for the parent nodes.
    */
    parentNodeLeftMargin: number;
    static ngAcceptInputType_parentNodeLeftMargin: number | string;
    /**
     * Gets or sets the top margin to use for the parent nodes.
    */
    parentNodeTopMargin: number;
    static ngAcceptInputType_parentNodeTopMargin: number | string;
    /**
     * Gets or sets the right margin to use for the parent nodes.
    */
    parentNodeRightMargin: number;
    static ngAcceptInputType_parentNodeRightMargin: number | string;
    /**
     * Gets or sets the bottom margin to use for the parent nodes.
    */
    parentNodeBottomMargin: number;
    static ngAcceptInputType_parentNodeBottomMargin: number | string;
    /**
     * Gets or sets the left padding to use for the parent nodes.
    */
    parentNodeLeftPadding: number;
    static ngAcceptInputType_parentNodeLeftPadding: number | string;
    /**
     * Gets or sets the top padding to use for the parent nodes.
    */
    parentNodeTopPadding: number;
    static ngAcceptInputType_parentNodeTopPadding: number | string;
    /**
     * Gets or sets the right padding to use for the parent nodes.
    */
    parentNodeRightPadding: number;
    static ngAcceptInputType_parentNodeRightPadding: number | string;
    /**
     * Gets or sets the bottom padding to use for the parent nodes.
    */
    parentNodeBottomPadding: number;
    static ngAcceptInputType_parentNodeBottomPadding: number | string;
    /**
     * Gets or sets the horizontal alignment to use for the node labels.
    */
    labelHorizontalAlignment: HorizontalAlignment;
    static ngAcceptInputType_labelHorizontalAlignment: HorizontalAlignment | string;
    /**
     * Gets or sets the vertical alignment to use for the node labels.
    */
    labelVerticalAlignment: VerticalAlignment;
    static ngAcceptInputType_labelVerticalAlignment: VerticalAlignment | string;
    /**
     * Gets or sets the height to use for the header.
    */
    headerHeight: number;
    static ngAcceptInputType_headerHeight: number | string;
    /**
     * Gets or sets the outline to use for the nodes.
    */
    outline: string;
    /**
     * Gets or sets the stroke thickness to use for the node outline.
    */
    strokeThickness: number;
    static ngAcceptInputType_strokeThickness: number | string;
    /**
     * Gets or sets the orientation to use for the stripped and slice and dice layout types.
    */
    layoutOrientation: TreemapOrientation;
    static ngAcceptInputType_layoutOrientation: TreemapOrientation | string;
    /**
     * Gets or sets the type of layout to use for the nodes.
    */
    layoutType: TreemapLayoutType;
    static ngAcceptInputType_layoutType: TreemapLayoutType | string;
    /**
     * Gets or sets the minimum size (width or height) to display a node.
    */
    minimumDisplaySize: number;
    static ngAcceptInputType_minimumDisplaySize: number | string;
    /**
     * Gets or sets the number of milliseconds over which changes to the gauge should be animated.
    */
    transitionDuration: number;
    static ngAcceptInputType_transitionDuration: number | string;
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    pixelScalingRatio: number;
    static ngAcceptInputType_pixelScalingRatio: number | string;
    actualPixelScalingRatio: number;
    static ngAcceptInputType_actualPixelScalingRatio: number | string;
    /**
     * Gets or sets the scaling value used to affect the pixel density of the control while it is animating.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    interactionPixelScalingRatio: number;
    static ngAcceptInputType_interactionPixelScalingRatio: number | string;
    /**
     * Gets or sets the resolved scaling value used to affect the pixel density of the control while it is animating.
     * A higher scaling ratio will produce crisper visuals at the expense of memory.  Lower values will cause the control
     * to appear blurry.
    */
    actualInteractionPixelScalingRatio: number;
    static ngAcceptInputType_actualInteractionPixelScalingRatio: number | string;
    readonly animating: boolean;
    static ngAcceptInputType_animating: boolean | string;
    /**
     * Gets or sets the item to drill to in the treemap.
    */
    focusItem: any;
    findByName(name: string): any;
    protected __p: string;
    protected _hasUserValues: Set<string>;
    protected readonly hasUserValues: Set<string>;
    protected __m(propertyName: string): void;
    protected _stylingContainer: any;
    protected _stylingParent: any;
    protected _inStyling: boolean;
    protected _styling(container: any, component: any, parent?: any): void;
    /**
 * Returns visuals as a serialized string.

*/
    exportSerializedVisualData(): string;
    markDirty(): void;
    onDetachedFromUI(): void;
    onAttachedToUI(): void;
    flush(): void;
    notifySetItem(source_: any, index: number, oldItem: any, newItem: any): void;
    /**
     * Manually notifies the treemap's data source that the data it has bound to has been cleared and needs to be re-examined.
     * This should not be called if the data that the pie chart is bound to is already observable.
    
    * @param source_  * The data source.
    */
    notifyClearItems(source_: any): void;
    notifyInsertItem(source_: any, index: number, newItem: any): void;
    notifyRemoveItem(source_: any, index: number, oldItem: any): void;
    simulateHover(point: IgPoint): void;
    private _nodeStyling;
    /**
     * Fired when a node is being styled. Provides an opportunity to customize node styling.
    */
    readonly nodeStyling: EventEmitter<{
        sender: any;
        args: IgxTreemapNodeStylingEventArgs;
    }>;
    private _nodePointerOver;
    /**
     * Fired with the pointer is moving over a node.
    */
    readonly nodePointerOver: EventEmitter<{
        sender: any;
        args: IgxTreemapNodePointerEventArgs;
    }>;
    private _nodePointerEnter;
    /**
     * Fired when the pointer enters a node.
    */
    readonly nodePointerEnter: EventEmitter<{
        sender: any;
        args: IgxTreemapNodePointerEventArgs;
    }>;
    private _nodePointerLeave;
    /**
     * Fired when the pointer leaved a node.
    */
    readonly nodePointerLeave: EventEmitter<{
        sender: any;
        args: IgxTreemapNodePointerEventArgs;
    }>;
    private _nodePointerPressed;
    /**
     * Fired when the pointer is pressed on a node.
    */
    readonly nodePointerPressed: EventEmitter<{
        sender: any;
        args: IgxTreemapNodePointerEventArgs;
    }>;
    private _nodePointerReleased;
    /**
     * Fired when the pointer is released on a node.
    */
    readonly nodePointerReleased: EventEmitter<{
        sender: any;
        args: IgxTreemapNodePointerEventArgs;
    }>;
    protected _zoneRunner: (act: () => void) => void;
    protected _runInZone(act: () => void): void;
}
